Redirecting IRCBot
===================

The bot will connect to an IRC server and whenever a message is sent to him, he
will respond with "The user you are trying to reach is known under nickname
<yournickname>"

Example config at redirbot/data/config/

Installation
============

openSUSE
--------
Available at `OpenSUSE buildservice <https://build.opensuse.org/package/show?package=python-redirbot&project=home%3Ayac>`_.

Gentoo
------
::

    # emerge redirbot

others
------
::

    python setup.py install

Support
=======

Github issues or highlight me in #yacdev@freenode
